==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translation>Keine Kontur selektiert.</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translation>Kontur nicht geschlossen am Punkt %1/%2.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation>Jedes Konturelement muss eine Linie, ein Bogen, ein Kreis, ein Ellipsenbogen, eine Ellipse, eine Polylinie oder Spline sein. Gefunden:</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found: </source>
        <translation type="obsolete">Jedes Konturelement muss eine Linie, ein Bogen, ein Kreis, ein Ellipsenbogen, eine Ellipse, eine Polylinie oder Spline sein. Gefunden:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Schraffur</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translation>Schraffur oder Füllung</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Schraffur</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Solide Füllung</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Schraffurmuster</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Muster</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Winkel:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Skalierung:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translation type="vanished">Keine Kontur selektiert.</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translation type="vanished">Kontur nicht geschlossen am Punkt %1/%2.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation type="vanished">Jedes Konturelement muss eine Linie, ein Bogen, ein Kreis, ein Ellipsenbogen, eine Ellipse, eine Polylinie oder Spline sein. Gefunden:</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found: </source>
        <translation type="obsolete">Jedes Konturelement muss eine Linie, ein Bogen, ein Kreis, ein Ellipsenbogen, eine Ellipse, eine Polylinie oder Spline sein. Gefunden:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>Schraffurwerkzeuge</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>Schraffurwerkzeuge anzeigen</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Schraffur</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translation type="vanished">Schraffur oder Füllung</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Schraffur</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Solide Füllung</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Schraffurmuster</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Muster</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Winkel:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Skalierung:</translation>
    </message>
</context>
</TS>
